mws — boto v2.27.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »

# mws

## boto.mws

## boto.mws.connection

class `boto.mws.connection.` `MWSConnection`(*args, **kw)
  class `ResponseErrorFactory`(scopes=None)
  class `MWSConnection.` `ResponseFactory`(scopes=None)
    `element_factory`(name, parent)
    `find_element`(action, suffix, parent)
    `search_scopes`(key)
  `MWSConnection.` `authorize`(*args, **kw)

    MWS Authorize/2013-01-01 API call; quota=10 restore=1.00 Reserves a specified amount against the payment method(s) stored in

    > the order reference.

    Element|Iter|Map: AuthorizationAmount (ResponseElement or anything iterable/dict-like) Required: AmazonOrderReferenceId+AuthorizationReferenceId+AuthorizationAmount

  `MWSConnection.` `cancel_feed_submissions`(*args, **kw)

    MWS CancelFeedSubmissions/2009-01-01 API call; quota=10 restore=45.00 Cancels one or more feed submissions and returns a

    > count of the feed submissions that were canceled.

    Lists: FeedSubmissionIdList.Id, FeedTypeList.Type

  `MWSConnection.` `cancel_fulfillment_order`(*args, **kw)

    MWS CancelFulfillmentOrder/2010-10-01 API call; quota=30 restore=0.50 Requests that Amazon stop attempting to fulfill an existing

    > fulfillment order.

    Required: SellerFulfillmentOrderId

  `MWSConnection.` `cancel_order_reference`(*args, **kw)

    MWS CancelOrderReference/2013-01-01 API call; quota=10 restore=1.00 Cancel an order reference; all authorizations associated with

    > this order reference are also closed.

    Required: AmazonOrderReferenceId

  `MWSConnection.` `cancel_report_requests`(*args, **kw)

    MWS CancelReportRequests/2009-01-01 API call; quota=10 restore=45.00 Cancel one or more report requests, returning the count of the canceled report requests and the report request information.

  `MWSConnection.` `capture`(*args, **kw)

    MWS Capture/2013-01-01 API call; quota=10 restore=1.00 Captures funds from an authorized payment instrument.

    Element|Iter|Map: CaptureAmount (ResponseElement or anything iterable/dict-like) Required: AmazonAuthorizationId+CaptureReferenceId+CaptureAmount

  `MWSConnection.` `close_authorization`(*args, **kw)

    MWS CloseAuthorization/2013-01-01 API call; quota=10 restore=1.00 Closes an authorization.

    Required: AmazonAuthorizationId

  `MWSConnection.` `close_order_reference`(*args, **kw)

    MWS CloseOrderReference/2013-01-01 API call; quota=10 restore=1.00 Confirms that an order reference has been fulfilled (fully

    > or partially) and that you do not expect to create any new authorizations on this order reference.

    Required: AmazonOrderReferenceId

  `MWSConnection.` `confirm_order_reference`(*args, **kw)

    MWS ConfirmOrderReference/2013-01-01 API call; quota=10 restore=1.00 Confirms that the order reference is free of constraints and all

    > required information has been set on the order reference.

    Required: AmazonOrderReferenceId

  `MWSConnection.` `create_fulfillment_order`(*args, **kw)

    MWS CreateFulfillmentOrder/2010-10-01 API call; quota=30 restore=0.50 Requests that Amazon ship items from the seller’s inventory

    > to a destination address.

    Required: SellerFulfillmentOrderId+DisplayableOrderId+ShippingSpeedCategory+DisplayableOrderDateTime+DestinationAddress+DisplayableOrderComment+Items Element|Iter|Map: DestinationAddress, Items (ResponseElement or anything iterable/dict-like)

  `MWSConnection.` `create_inbound_shipment`(*args, **kw)

    MWS CreateInboundShipment/2010-10-01 API call; quota=30 restore=0.50 Creates an inbound shipment.

    Element|Iter|Map: InboundShipmentHeader, InboundShipmentItems (ResponseElement or anything iterable/dict-like) Required: ShipmentId+InboundShipmentHeader+InboundShipmentItems

  `MWSConnection.` `create_inbound_shipment_plan`(*args, **kw)

    MWS CreateInboundShipmentPlan/2010-10-01 API call; quota=30 restore=0.50 Returns the information required to create an inbound shipment.

    Element|Iter|Map: ShipFromAddress, InboundShipmentPlanRequestItems (ResponseElement or anything iterable/dict-like) Required: ShipFromAddress+InboundShipmentPlanRequestItems

  `MWSConnection.` `create_subscription`(*args, **kw)

    MWS CreateSubscription/2013-07-01 API call; quota=25 restore=0.50 Creates a new subscription for the specified notification type

    > and destination.

    Element|Iter|Map: Subscription (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+Subscription

  `MWSConnection.` `delete_subscription`(*args, **kw)

    MWS DeleteSubscription/2013-07-01 API call; quota=25 restore=0.50 Deletes the subscription for the specified notification type and

    > destination.

    Element|Iter|Map: Destination (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+NotificationType+Destination

  `MWSConnection.` `deregister_destination`(*args, **kw)

    MWS DeregisterDestination/2013-07-01 API call; quota=25 restore=0.50 Removes an existing destination from the list of registered

    > destinations.

    Element|Iter|Map: Destination (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+Destination

  `MWSConnection.` `get_authorization_details`(*args, **kw)

    MWS GetAuthorizationDetails/2013-01-01 API call; quota=20 restore=2.00 Returns the status of a particular authorization and the total

    > amount captured on the authorization.

    Required: AmazonAuthorizationId

  `MWSConnection.` `get_capture_details`(*args, **kw)

    MWS GetCaptureDetails/2013-01-01 API call; quota=20 restore=2.00 Returns the status of a particular capture and the total amount

    > refunded on the capture.

    Required: AmazonCaptureId

  `MWSConnection.` `get_cartinfo_service_status`(*args, **kw)

    MWS GetServiceStatus/2014-03-01 API call; quota=2 restore=300.00 Returns the operational status of the Cart Information API section.

  `MWSConnection.` `get_carts`(*args, **kw)

    MWS GetCarts/2014-03-01 API call; quota=15 restore=12.00 Returns shopping carts based on the CartId values that you specify.

    Lists: CartIdList.CartId Required: CartIdList

  `MWSConnection.` `get_competitive_pricing_for_asin`(*args, **kw)

    MWS GetCompetitivePricingForASIN/2011-10-01 API call; quota=20 restore=10.00 Returns the current competitive pricing of a product,

    > based on the ASINs and MarketplaceId that you specify.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `MWSConnection.` `get_competitive_pricing_for_sku`(*args, **kw)

    MWS GetCompetitivePricingForSKU/2011-10-01 API call; quota=20 restore=10.00 Returns the current competitive pricing of a product,

    > based on the SellerSKUs and MarketplaceId that you specify.

    Lists: SellerSKUList.SellerSKU Required: MarketplaceId+SellerSKUList

  `MWSConnection.` `get_customerinfo_service_status`(*args, **kw)

    MWS GetServiceStatus/2014-03-01 API call; quota=2 restore=300.00 Returns the operational status of the Customer Information API section.

  `MWSConnection.` `get_customers_for_customer_id`(*args, **kw)

    MWS GetCustomersForCustomerId/2014-03-01 API call; quota=15 restore=12.00 Returns a list of customer accounts based on search criteria that

    > you specify.

    Lists: CustomerIdList.CustomerId Required: CustomerIdList

  `MWSConnection.` `get_feed_submission_count`(*args, **kw)

    MWS GetFeedSubmissionCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of the feeds submitted in the previous 90 days.

    Lists: FeedTypeList.Type, FeedProcessingStatusList.Status

  `MWSConnection.` `get_feed_submission_list`(*args, **kw)

    MWS GetFeedSubmissionList/2009-01-01 API call; quota=10 restore=45.00 Returns a list of all feed submissions submitted in the

    > previous 90 days.

    Lists: FeedSubmissionIdList.Id, FeedTypeList.Type, FeedProcessingStatusList.Status

  `MWSConnection.` `get_feed_submission_list_by_next_token`(*args, **kw)

    MWS GetFeedSubmissionListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of feed submissions using the NextToken parameter.

    Required: NextToken

  `MWSConnection.` `get_feed_submission_result`(*args, **kw)

    MWS GetFeedSubmissionResult/2009-01-01 API call; quota=15 restore=60.00 Returns the feed processing report.

    Required: FeedSubmissionId

  `MWSConnection.` `get_fulfillment_order`(*args, **kw)

    MWS GetFulfillmentOrder/2010-10-01 API call; quota=30 restore=0.50 Returns a fulfillment order based on a specified

    > SellerFulfillmentOrderId.

    Required: SellerFulfillmentOrderId

  `MWSConnection.` `get_fulfillment_preview`(*args, **kw)

    MWS GetFulfillmentPreview/2010-10-01 API call; quota=30 restore=0.50 Returns a list of fulfillment order previews based on items

    > and shipping speed categories that you specify.

    Required: Address+Items Element|Iter|Map: Address, Items (ResponseElement or anything iterable/dict-like)

  `MWSConnection.` `get_inbound_service_status`(*args, **kw)

    MWS GetServiceStatus/2010-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Fulfillment Inbound Shipment API section.

  `MWSConnection.` `get_inventory_service_status`(*args, **kw)

    MWS GetServiceStatus/2010-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Fulfillment Inventory API section.

  `MWSConnection.` `get_last_updated_time_for_recommendations`(*args, **kw)

    MWS GetLastUpdatedTimeForRecommendations/2013-04-01 API call; quota=5 restore=2.00 Checks whether there are active recommendations for each category

    > for the given marketplace, and if there are, returns the time when recommendations were last updated for each category.

    Required: MarketplaceId

  `MWSConnection.` `get_lowest_offer_listings_for_asin`(*args, **kw)

    MWS GetLowestOfferListingsForASIN/2011-10-01 API call; quota=20 restore=5.00 Returns the lowest price offer listings for a specific

    > product by item condition and ASINs.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `MWSConnection.` `get_lowest_offer_listings_for_sku`(*args, **kw)

    MWS GetLowestOfferListingsForSKU/2011-10-01 API call; quota=20 restore=5.00 Returns the lowest price offer listings for a specific

    > product by item condition and SellerSKUs.

    Lists: SellerSKUList.SellerSKU Required: MarketplaceId+SellerSKUList

  `MWSConnection.` `get_matching_product`(*args, **kw)

    MWS GetMatchingProduct/2011-10-01 API call; quota=20 restore=20.00 Returns a list of products and their attributes, based on

    > a list of ASIN values that you specify.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `MWSConnection.` `get_matching_product_for_id`(*args, **kw)

    MWS GetMatchingProductForId/2011-10-01 API call; quota=20 restore=20.00 Returns a list of products and their attributes, based on

    > a list of Product IDs that you specify.

    Lists: IdList.Id Required: MarketplaceId+IdType+IdList

  `MWSConnection.` `get_my_price_for_asin`(*args, **kw)

    MWS GetMyPriceForASIN/2011-10-01 API call; quota=20 restore=10.00 Returns pricing information for your own offer listings, based on ASIN.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `MWSConnection.` `get_my_price_for_sku`(*args, **kw)

    MWS GetMyPriceForSKU/2011-10-01 API call; quota=20 restore=10.00 Returns pricing information for your own offer listings, based on SellerSKU.

    Lists: SellerSKUList.SellerSKU Required: MarketplaceId+SellerSKUList

  `MWSConnection.` `get_offamazonpayments_service_status`(*args, **kw)

    MWS GetServiceStatus/2013-01-01 API call; quota=2 restore=300.00 Returns the operational status of the Off-Amazon Payments API section.

  `MWSConnection.` `get_order`(*args, **kw)

    MWS GetOrder/2013-09-01 API call; quota=6 restore=60.00 Returns an order for each AmazonOrderId that you specify.

    Lists: AmazonOrderId.Id Required: AmazonOrderId

  `MWSConnection.` `get_order_reference_details`(*args, **kw)

    MWS GetOrderReferenceDetails/2013-01-01 API call; quota=20 restore=2.00 Returns details about the Order Reference object and its current

    > state.

    Required: AmazonOrderReferenceId

  `MWSConnection.` `get_orders_service_status`(*args, **kw)

    MWS GetServiceStatus/2013-09-01 API call; quota=2 restore=300.00 Returns the operational status of the Orders API section.

  `MWSConnection.` `get_outbound_service_status`(*args, **kw)

    MWS GetServiceStatus/2010-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Fulfillment Outbound API section.

  `MWSConnection.` `get_package_tracking_details`(*args, **kw)

    MWS GetPackageTrackingDetails/2010-10-01 API call; quota=30 restore=0.50 Returns delivery tracking information for a package in

    > an outbound shipment for a Multi-Channel Fulfillment order.

    Required: PackageNumber

  `MWSConnection.` `get_product_categories_for_asin`(*args, **kw)

    MWS GetProductCategoriesForASIN/2011-10-01 API call; quota=20 restore=20.00 Returns the product categories that an ASIN belongs to.

    Required: MarketplaceId+ASIN

  `MWSConnection.` `get_product_categories_for_sku`(*args, **kw)

    MWS GetProductCategoriesForSKU/2011-10-01 API call; quota=20 restore=20.00 Returns the product categories that a SellerSKU belongs to.

    Required: MarketplaceId+SellerSKU

  `MWSConnection.` `get_products_service_status`(*args, **kw)

    MWS GetServiceStatus/2011-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Products API section.

  `MWSConnection.` `get_recommendations_service_status`(*args, **kw)

    MWS GetServiceStatus/2013-04-01 API call; quota=2 restore=300.00 Returns the operational status of the Recommendations API section.

  `MWSConnection.` `get_refund_details`(*args, **kw)

    MWS GetRefundDetails/2013-01-01 API call; quota=20 restore=2.00 Returns the status of a particular refund.

    Required: AmazonRefundId

  `MWSConnection.` `get_report`(*args, **kw)

    MWS GetReport/2009-01-01 API call; quota=15 restore=60.00 Returns the contents of a report.

    Required: ReportId

  `MWSConnection.` `get_report_count`(*args, **kw)

    MWS GetReportCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of the reports, created in the previous 90 days,

    > with a status of _DONE_ and that are available for download.

    Lists: ReportTypeList.Type Booleans: Acknowledged

  `MWSConnection.` `get_report_list`(*args, **kw)

    MWS GetReportList/2009-01-01 API call; quota=10 restore=60.00 Returns a list of reports that were created in the previous

    > 90 days that match the query parameters.

    Lists: ReportRequestIdList.Id, ReportTypeList.Type Booleans: Acknowledged

  `MWSConnection.` `get_report_list_by_next_token`(*args, **kw)

    MWS GetReportListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of reports using the NextToken, which

    > was supplied by a previous request to either GetReportListByNextToken or GetReportList, where the value of HasNext was true in the previous call.

    Required: NextToken

  `MWSConnection.` `get_report_request_count`(*args, **kw)

    MWS GetReportRequestCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of report requests that have been submitted

    > to Amazon MWS for processing.

    Lists: ReportTypeList.Type, ReportProcessingStatusList.Status

  `MWSConnection.` `get_report_request_list`(*args, **kw)

    MWS GetReportRequestList/2009-01-01 API call; quota=10 restore=45.00 Returns a list of report requests that you can use to get the

    > ReportRequestId for a report.

    Lists: ReportRequestIdList.Id, ReportTypeList.Type, ReportProcessingStatusList.Status

  `MWSConnection.` `get_report_request_list_by_next_token`(*args, **kw)

    MWS GetReportRequestListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of report requests using the NextToken,

    > which was supplied by a previous request to either GetReportRequestListByNextToken or GetReportRequestList, where the value of HasNext was true in that previous request.

    Required: NextToken

  `MWSConnection.` `get_report_schedule_count`(*args, **kw)

    MWS GetReportScheduleCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of order report requests that are scheduled

    > to be submitted to Amazon MWS.

    Lists: ReportTypeList.Type

  `MWSConnection.` `get_report_schedule_list`(*args, **kw)

    MWS GetReportScheduleList/2009-01-01 API call; quota=10 restore=45.00 Returns a list of order report requests that are scheduled

    > to be submitted to Amazon MWS for processing.

    Lists: ReportTypeList.Type

  `MWSConnection.` `get_report_schedule_list_by_next_token`(*args, **kw)

    MWS GetReportScheduleListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of report requests using the NextToken,

    > which was supplied by a previous request to either GetReportScheduleListByNextToken or GetReportScheduleList, where the value of HasNext was true in that previous request.

    Required: NextToken

  `MWSConnection.` `get_service_status`(**kw)

    Instruct the user on how to get service status.

  `MWSConnection.` `get_subscription`(*args, **kw)

    MWS GetSubscription/2013-07-01 API call; quota=25 restore=0.50 Gets the subscription for the specified notification type and

    > destination.

    Element|Iter|Map: Destination (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+NotificationType+Destination

  `MWSConnection.` `get_subscriptions_service_status`(*args, **kw)

    MWS GetServiceStatus/2013-07-01 API call; quota=2 restore=300.00 Returns the operational status of the Subscriptions API section.

  `MWSConnection.` `iter_call`(call, *args, **kw)

    Pass a call name as the first argument and a generator is returned for the initial response and any continuation call responses made using the NextToken.

  `MWSConnection.` `iter_response`(response)

    Pass a call’s response as the initial argument and a generator is returned for the initial response and any continuation call responses made using the NextToken.

  `MWSConnection.` `list_all_fulfillment_orders`(*args, **kw)

    MWS ListAllFulfillmentOrders/2010-10-01 API call; quota=30 restore=0.50 Returns a list of fulfillment orders fulfilled after (or at) a specified date or by fulfillment method.

  `MWSConnection.` `list_all_fulfillment_orders_by_next_token`(*args, **kw)

    MWS ListAllFulfillmentOrdersByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of inbound shipment items using the

    > NextToken parameter.

    Required: NextToken

  `MWSConnection.` `list_carts`(*args, **kw)

    MWS ListCarts/2014-03-01 API call; quota=15 restore=12.00 Returns a list of shopping carts in your Webstore that were last

    > updated during the time range that you specify.

    Required: DateRangeStart

  `MWSConnection.` `list_carts_by_next_token`(*args, **kw)

    MWS ListCartsByNextToken/2014-03-01 API call; quota=50 restore=3.00 Returns the next page of shopping carts using the NextToken

    > parameter.

    Required: NextToken

  `MWSConnection.` `list_customers`(*args, **kw)

    MWS ListCustomers/2014-03-01 API call; quota=15 restore=12.00 Returns a list of customer accounts based on search criteria that you specify.

  `MWSConnection.` `list_customers_by_next_token`(*args, **kw)

    MWS ListCustomersByNextToken/2014-03-01 API call; quota=50 restore=3.00 Returns the next page of customers using the NextToken parameter.

    Required: NextToken

  `MWSConnection.` `list_inbound_shipment_items`(*args, **kw)

    MWS ListInboundShipmentItems/2010-10-01 API call; quota=30 restore=0.50 Returns a list of items in a specified inbound shipment, or a

    > list of items that were updated within a specified time frame.

    Required: ShipmentId OR LastUpdatedAfter+LastUpdatedBefore

  `MWSConnection.` `list_inbound_shipment_items_by_next_token`(*args, **kw)

    MWS ListInboundShipmentItemsByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of inbound shipment items using the

    > NextToken parameter.

    Required: NextToken

  `MWSConnection.` `list_inbound_shipments`(*args, **kw)

    MWS ListInboundShipments/2010-10-01 API call; quota=30 restore=0.50 Returns a list of inbound shipments based on criteria that

    > you specify.

    Lists: ShipmentIdList.Id, ShipmentStatusList.Status Some Required: ShipmentIdList, ShipmentStatusList

  `MWSConnection.` `list_inbound_shipments_by_next_token`(*args, **kw)

    MWS ListInboundShipmentsByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of inbound shipments using the NextToken

    > parameter.

    Required: NextToken

  `MWSConnection.` `list_inventory_supply`(*args, **kw)

    MWS ListInventorySupply/2010-10-01 API call; quota=30 restore=0.50 Returns information about the availability of a seller’s

    > inventory.

    Lists: SellerSkus.member Required: SellerSkus OR QueryStartDateTime

  `MWSConnection.` `list_inventory_supply_by_next_token`(*args, **kw)

    MWS ListInventorySupplyByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of information about the availability

    > of a seller’s inventory using the NextToken parameter.

    Required: NextToken

  `MWSConnection.` `list_marketplace_participations`(*args, **kw)

    MWS ListMarketplaceParticipations/2011-07-01 API call; quota=15 restore=60.00 Returns a list of marketplaces that the seller submitting the request can sell in, and a list of participations that include seller-specific information in that marketplace.

  `MWSConnection.` `list_marketplace_participations_by_next_token`(*args, **kw)

    MWS ListMarketplaceParticipationsByNextToken/2011-07-01 API call; quota=15 restore=60.00 Returns the next page of marketplaces and participations

    > using the NextToken value that was returned by your previous request to either ListMarketplaceParticipations or ListMarketplaceParticipationsByNextToken.

    Required: NextToken

  `MWSConnection.` `list_matching_products`(*args, **kw)

    MWS ListMatchingProducts/2011-10-01 API call; quota=20 restore=20.00 Returns a list of products and their attributes, ordered

    > by relevancy, based on a search query that you specify.

    Required: MarketplaceId+Query

  `MWSConnection.` `list_order_items`(*args, **kw)

    MWS ListOrderItems/2013-09-01 API call; quota=30 restore=2.00 Returns order item information for an AmazonOrderId that

    > you specify.

    Required: AmazonOrderId

  `MWSConnection.` `list_order_items_by_next_token`(*args, **kw)

    MWS ListOrderItemsByNextToken/2013-09-01 API call; quota=30 restore=2.00 Returns the next page of order items using the NextToken

    > value that was returned by your previous request to either ListOrderItems or ListOrderItemsByNextToken.

    Required: NextToken

  `MWSConnection.` `list_orders`(*args, **kw)

    MWS ListOrders/2013-09-01 API call; quota=6 restore=60.00 Returns a list of orders created or updated during a time

    > frame that you specify.

    Lists: MarketplaceId.Id, OrderStatus.Status, FulfillmentChannel.Channel, PaymentMethod. Element|Iter|Map: OrderTotal, ShippingAddress, PaymentExecutionDetail (ResponseElement or anything iterable/dict-like) Required: MarketplaceId Either: CreatedAfter OR LastUpdatedBefore LastUpdatedBefore requires: LastUpdatedAfter Either: LastUpdatedAfter OR BuyerEmail OR SellerOrderId CreatedBefore requires: CreatedAfter Either: CreatedAfter OR LastUpdatedAfter Required: CreatedAfter OR LastUpdatedAfter

  `MWSConnection.` `list_orders_by_next_token`(*args, **kw)

    MWS ListOrdersByNextToken/2013-09-01 API call; quota=6 restore=60.00 Returns the next page of orders using the NextToken value

    > that was returned by your previous request to either ListOrders or ListOrdersByNextToken.

    Required: NextToken

  `MWSConnection.` `list_recommendations`(*args, **kw)

    MWS ListRecommendations/2013-04-01 API call; quota=5 restore=2.00 Returns your active recommendations for a specific category or for

    > all categories for a specific marketplace.

    Lists: CategoryQueryList.CategoryQuery Required: MarketplaceId

  `MWSConnection.` `list_recommendations_by_next_token`(*args, **kw)

    MWS ListRecommendationsByNextToken/2013-04-01 API call; quota=5 restore=2.00 Returns the next page of recommendations using the NextToken

    > parameter.

    Required: NextToken

  `MWSConnection.` `list_registered_destinations`(*args, **kw)

    MWS ListRegisteredDestinations/2013-07-01 API call; quota=25 restore=0.50 Lists all current destinations that you have registered.

    Required: MarketplaceId

  `MWSConnection.` `list_subscriptions`(*args, **kw)

    MWS ListSubscriptions/2013-07-01 API call; quota=25 restore=0.50 Returns a list of all your current subscriptions.

    Required: MarketplaceId

  `MWSConnection.` `manage_report_schedule`(*args, **kw)

    MWS ManageReportSchedule/2009-01-01 API call; quota=10 restore=45.00 Creates, updates, or deletes a report request schedule for

    > a specified report type.

    Required: ReportType+Schedule

  `MWSConnection.` `method_for`(name)

    Return the MWS API method referred to in the argument. The named method can be in CamelCase or underlined_lower_case. This is the complement to MWSConnection.any_call.action

  `MWSConnection.` `refund`(*args, **kw)

    MWS Refund/2013-01-01 API call; quota=10 restore=1.00 Refunds a previously captured amount.

    Element|Iter|Map: RefundAmount (ResponseElement or anything iterable/dict-like) Required: AmazonCaptureId+RefundReferenceId+RefundAmount

  `MWSConnection.` `register_destination`(*args, **kw)

    MWS RegisterDestination/2013-07-01 API call; quota=25 restore=0.50 Specifies a new destination where you want to receive notifications.

    Element|Iter|Map: Destination (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+Destination

  `MWSConnection.` `request_report`(*args, **kw)

    MWS RequestReport/2009-01-01 API call; quota=15 restore=60.00 Creates a report request and submits the request to Amazon MWS.

    Required: ReportType Booleans: ReportOptions=ShowSalesChannel Lists: MarketplaceIdList.Id

  `MWSConnection.` `send_test_notification_to_destination`(*args, **kw)

    MWS SendTestNotificationToDestination/2013-07-01 API call; quota=25 restore=0.50 Sends a test notification to an existing destination.

    Element|Iter|Map: Destination (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+Destination

  `MWSConnection.` `set_order_reference_details`(*args, **kw)

    MWS SetOrderReferenceDetails/2013-01-01 API call; quota=10 restore=1.00 Sets order reference details such as the order total and a

    > description for the order.

    Element|Iter|Map: OrderReferenceAttributes (ResponseElement or anything iterable/dict-like) Required: AmazonOrderReferenceId+OrderReferenceAttributes

  `MWSConnection.` `submit_feed`(*args, **kw)

    MWS SubmitFeed/2009-01-01 API call; quota=15 restore=120.00 Uploads a feed for processing by Amazon MWS.

    Required: FeedType Lists: MarketplaceIdList.Id Required HTTP Body: FeedContent Booleans: PurgeAndReplace

  `MWSConnection.` `update_inbound_shipment`(*args, **kw)

    MWS UpdateInboundShipment/2010-10-01 API call; quota=30 restore=0.50 Updates an existing inbound shipment. Amazon documentation

    > is ambiguous as to whether the InboundShipmentHeader and InboundShipmentItems arguments are required.

    Element|Iter|Map: InboundShipmentHeader, InboundShipmentItems (ResponseElement or anything iterable/dict-like) Required: ShipmentId

  `MWSConnection.` `update_report_acknowledgements`(*args, **kw)

    MWS UpdateReportAcknowledgements/2009-01-01 API call; quota=10 restore=45.00 Updates the acknowledged status of one or more reports.

    Lists: ReportIdList.Id Required: ReportIdList Booleans: Acknowledged

  `MWSConnection.` `update_subscription`(*args, **kw)

    MWS UpdateSubscription/2013-07-01 API call; quota=25 restore=0.50 Updates the subscription for the specified notification type and

    > destination.

    Element|Iter|Map: Subscription (ResponseElement or anything iterable/dict-like) Required: MarketplaceId+Subscription

## boto.mws.exception

exception `boto.mws.exception.` `InvalidAddress`(status, reason, body=None, *args)

  Invalid address.

exception `boto.mws.exception.` `InvalidParameter`(status, reason, body=None, *args)

  One or more parameters in the request is invalid.

exception `boto.mws.exception.` `InvalidParameterValue`(status, reason, body=None, *args)

  One or more parameter values in the request is invalid.

exception `boto.mws.exception.` `ResponseError`(status, reason, body=None, *args)

  Undefined response error.

  `retry` = False

class `boto.mws.exception.` `ResponseErrorFactory`(scopes=None)

exception `boto.mws.exception.` `RetriableResponseError`(status, reason, body=None, *args)
  `retry` = True

## boto.mws.response

class `boto.mws.response.` `AttributeSet`(connection=None, name=None, parent=None, attrs=None)
  `ItemDimensions` = <Element_?/?_0x7ffd26b0f6e0>
  `ListPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `PackageDimensions` = <Element_?/?_0x7ffd26b0f6e0>
  `SmallImage` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `AuthorizationDetails`(connection=None, name=None, parent=None, attrs=None)
  `AuthorizationAmount` = <Element_?/?_0x7ffd26b0f6e0>
  `AuthorizationFee` = <Element_?/?_0x7ffd26b0f6e0>
  `AuthorizationStatus` = <Element_?/?_0x7ffd26b0f6e0>
  `CapturedAmount` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `AuthorizeResult`(connection=None, name=None, parent=None, attrs=None)
  `AuthorizationDetails` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `CancelFeedSubmissionsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `CancelReportRequestsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `CaptureDetails`(connection=None, name=None, parent=None, attrs=None)
  `CaptureAmount` = <Element_?/?_0x7ffd26b0f6e0>
  `CaptureFee` = <Element_?/?_0x7ffd26b0f6e0>
  `CaptureStatus` = <Element_?/?_0x7ffd26b0f6e0>
  `RefundedAmount` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `CaptureResult`(connection=None, name=None, parent=None, attrs=None)
  `CaptureDetails` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Cart`(connection=None, name=None, parent=None, attrs=None)
  `ActiveCartItemList` = <Element_?/?_0x7ffd26b0f6e0>
  `SavedCartItemList` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `CartItem`(connection=None, name=None, parent=None, attrs=None)
  `CurrentPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `SalePrice` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `CompetitivePrice`(connection=None, name=None, parent=None, attrs=None)
  `Price` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `CompetitivePriceList`(connection=None, name=None, parent=None, attrs=None)
  `CompetitivePrice` = <ElementList_?/?_0x7ffd26e134c0>

class `boto.mws.response.` `CompetitivePricing`(connection=None, name=None, parent=None, attrs=None)
  `CompetitivePrices` = <Element_?/?_0x7ffd26b0f6e0>
  `NumberOfOfferListings` = <SimpleList_?/?_0x7ffd26b51b90>
  `TradeInValue` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ComplexAmount`(connection=None, name=None, parent=None, attrs=None)
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ComplexDimensions`(connection=None, name=None, parent=None, attrs=None)
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ComplexMoney`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ComplexType`

class `boto.mws.response.` `ComplexWeight`(connection=None, name=None, parent=None, attrs=None)
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `CreateInboundShipmentPlanResult`(connection=None, name=None, parent=None, attrs=None)
  `InboundShipmentPlans` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `Customer`(connection=None, name=None, parent=None, attrs=None)
  `AssociatedMarketplaces` = <Element_?/?_0x7ffd26b0f6e0>
  `PrimaryContactInfo` = <Element_?/?_0x7ffd26b0f6e0>
  `ShippingAddressList` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `DeclarativeType`(_hint=None, **kw)
  `end`(*args, **kw)
  `setup`(parent, name, *args, **kw)
  `start`(*args, **kw)
  `teardown`(*args, **kw)

class `boto.mws.response.` `Destination`(connection=None, name=None, parent=None, attrs=None)
  `AttributeList` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `Dimension`

class `boto.mws.response.` `Element`(_hint=None, **kw)
  `end`(*args, **kw)
  `start`(*args, **kw)

class `boto.mws.response.` `ElementList`(*args, **kw)
  `end`(*args, **kw)
  `start`(*args, **kw)

class `boto.mws.response.` `FeedSubmissionInfo`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `FulfillmentOrder`(connection=None, name=None, parent=None, attrs=None)
  `DestinationAddress` = <Element_?/?_0x7ffd26b0f6e0>
  `NotificationEmailList` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `FulfillmentPreview`(connection=None, name=None, parent=None, attrs=None)
  `EstimatedFees` = <MemberList_?/?_0x7ffd263ab640>
  `EstimatedShippingWeight` = <Element_?/?_0x7ffd26b0f6e0>
  `FulfillmentPreviewShipments` = <MemberList_?/?_0x7ffd263ab640>
  `UnfulfillablePreviewItems` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `FulfillmentPreviewItem`(connection=None, name=None, parent=None, attrs=None)
  `EstimatedShippingWeight` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `GetAuthorizationDetailsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetCaptureDetailsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetCartsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetCompetitivePricingForASINResponse`(*args, **kw)

class `boto.mws.response.` `GetCompetitivePricingForSKUResponse`(*args, **kw)

class `boto.mws.response.` `GetCustomersForCustomerIdResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetFeedSubmissionCountResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetFeedSubmissionListResult`(connection=None, name=None, parent=None, attrs=None)
  `FeedSubmissionInfo` = <ElementList_?/?_0x7ffd26e134c0>

class `boto.mws.response.` `GetFulfillmentOrderResult`(connection=None, name=None, parent=None, attrs=None)
  `FulfillmentOrder` = <Element_?/?_0x7ffd26b0f6e0>
  `FulfillmentOrderItem` = <MemberList_?/?_0x7ffd263ab640>
  `FulfillmentShipment` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `GetFulfillmentPreviewResult`(connection=None, name=None, parent=None, attrs=None)
  `FulfillmentPreviews` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `GetLowestOfferListingsForASINResponse`(*args, **kw)

class `boto.mws.response.` `GetLowestOfferListingsForSKUResponse`(*args, **kw)

class `boto.mws.response.` `GetMatchingProductForIdResponse`(*args, **kw)

class `boto.mws.response.` `GetMatchingProductForIdResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetMatchingProductResponse`(*args, **kw)

class `boto.mws.response.` `GetMyPriceForASINResponse`(*args, **kw)

class `boto.mws.response.` `GetMyPriceForSKUResponse`(*args, **kw)

class `boto.mws.response.` `GetOrderReferenceDetailsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetOrderResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetPackageTrackingDetailsResult`(connection=None, name=None, parent=None, attrs=None)
  `ShipToAddress` = <Element_?/?_0x7ffd26b0f6e0>
  `TrackingEvents` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `GetProductCategoriesForASINResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetProductCategoriesForSKUResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetProductCategoriesResult`(connection=None, name=None, parent=None, attrs=None)
  `Self` = <ElementList_?/?_0x7ffd26e134c0>

class `boto.mws.response.` `GetRefundDetails`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetReportListResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportInfo` = <ElementList_?/?_0x7ffd26e134c0>

class `boto.mws.response.` `GetReportRequestListResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportRequestInfo` = <ElementList_?/?_0x7ffd26e134c0>

class `boto.mws.response.` `GetReportScheduleListResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetServiceStatusResult`(connection=None, name=None, parent=None, attrs=None)
  `Messages` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `GetSubscriptionResult`(connection=None, name=None, parent=None, attrs=None)
  `Subscription` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Image`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ItemAttributes`(*args, **kw)
  `Languages` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListAllFulfillmentOrdersResult`(connection=None, name=None, parent=None, attrs=None)
  `FulfillmentOrders` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `ListCartsResult`(connection=None, name=None, parent=None, attrs=None)
  `CartList` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListCustomersResult`(connection=None, name=None, parent=None, attrs=None)
  `CustomerList` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListInboundShipmentItemsResult`(connection=None, name=None, parent=None, attrs=None)
  `ItemData` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `ListInboundShipmentsResult`(connection=None, name=None, parent=None, attrs=None)
  `ShipmentData` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `ListInventorySupplyResult`(connection=None, name=None, parent=None, attrs=None)
  `InventorySupplyList` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `ListMarketplaceParticipationsResult`(connection=None, name=None, parent=None, attrs=None)
  `ListMarketplaces` = <Element_?/?_0x7ffd26b0f6e0>
  `ListParticipations` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListMatchingProductsResult`(connection=None, name=None, parent=None, attrs=None)
  `Products` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListOrderItemsResult`(connection=None, name=None, parent=None, attrs=None)
  `OrderItems` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListOrdersResult`(connection=None, name=None, parent=None, attrs=None)
  `Orders` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ListRecommendationsResult`(connection=None, name=None, parent=None, attrs=None)
  `ListingQualityRecommendations` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `ListRegisteredDestinationsResult`(connection=None, name=None, parent=None, attrs=None)
  `DestinationList` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `ListSubscriptionsResult`(connection=None, name=None, parent=None, attrs=None)
  `SubscriptionList` = <MemberList_?/?_0x7ffd263ab640>

class `boto.mws.response.` `LowestOfferListing`(connection=None, name=None, parent=None, attrs=None)
  `Price` = <Element_?/?_0x7ffd26b0f6e0>
  `Qualifiers` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ManageReportScheduleResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportSchedule` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `MemberList`(_member=None, _hint=None, *args, **kw)
  `teardown`(*args, **kw)

class `boto.mws.response.` `Offer`(connection=None, name=None, parent=None, attrs=None)
  `BuyingPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `RegularPrice` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Order`(connection=None, name=None, parent=None, attrs=None)
  `OrderTotal` = <Element_?/?_0x7ffd26b0f6e0>
  `PaymentExecutionDetail` = <Element_?/?_0x7ffd26b0f6e0>
  `ShippingAddress` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `OrderItem`(connection=None, name=None, parent=None, attrs=None)
  `CODFee` = <Element_?/?_0x7ffd26b0f6e0>
  `CODFeeDiscount` = <Element_?/?_0x7ffd26b0f6e0>
  `GiftWrapPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `GiftWrapTax` = <Element_?/?_0x7ffd26b0f6e0>
  `ItemPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `ItemTax` = <Element_?/?_0x7ffd26b0f6e0>
  `PromotionDiscount` = <Element_?/?_0x7ffd26b0f6e0>
  `PromotionIds` = <SimpleList_?/?_0x7ffd26b51b90>
  `ShippingDiscount` = <Element_?/?_0x7ffd26b0f6e0>
  `ShippingPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `ShippingTax` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `OrderReferenceDetails`(connection=None, name=None, parent=None, attrs=None)
  `Buyer` = <Element_?/?_0x7ffd26b0f6e0>
  `Constraints` = <ElementList_?/?_0x7ffd26e134c0>
  `Destination` = <Element_?/?_0x7ffd26b0f6e0>
  `OrderReferenceStatus` = <Element_?/?_0x7ffd26b0f6e0>
  `OrderTotal` = <Element_?/?_0x7ffd26b0f6e0>
  `SellerOrderAttributes` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Price`(connection=None, name=None, parent=None, attrs=None)
  `LandedPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `ListingPrice` = <Element_?/?_0x7ffd26b0f6e0>
  `Shipping` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Product`(connection=None, name=None, parent=None, attrs=None)
  `AttributeSets` = <Element_?/?_0x7ffd26b0f6e0>
  `CompetitivePricing` = <ElementList_?/?_0x7ffd26e134c0>
  `Identifiers` = <Element_?/?_0x7ffd26b0f6e0>
  `LowestOfferListings` = <Element_?/?_0x7ffd26b0f6e0>
  `Offers` = <Element_?/?_0x7ffd26b0f6e0>
  `Relationships` = <Element_?/?_0x7ffd26b0f6e0>
  `SalesRankings` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ProductCategory`(*args, **kw)

class `boto.mws.response.` `ProductsBulkOperationResponse`(*args, **kw)

class `boto.mws.response.` `ProductsBulkOperationResult`(connection=None, name=None, parent=None, attrs=None)
  `Error` = <Element_?/?_0x7ffd26b0f6e0>
  `Product` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `RefundDetails`(connection=None, name=None, parent=None, attrs=None)
  `FeeRefunded` = <Element_?/?_0x7ffd26b0f6e0>
  `RefundAmount` = <Element_?/?_0x7ffd26b0f6e0>
  `RefundStatus` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `RefundResult`(connection=None, name=None, parent=None, attrs=None)
  `RefundDetails` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `ReportRequestInfo`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `RequestReportResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportRequestInfo` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Response`(connection=None, name=None, parent=None, attrs=None)
  `ResponseMetadata` = <Element_?/?_0x7ffd26b0f6e0>
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ResponseElement`(connection=None, name=None, parent=None, attrs=None)
  `connection`
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ResponseFactory`(scopes=None)
  `element_factory`(name, parent)
  `find_element`(action, suffix, parent)
  `search_scopes`(key)

class `boto.mws.response.` `ResponseResultList`(*args, **kw)

class `boto.mws.response.` `SalesRank`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `SetOrderReferenceDetailsResult`(connection=None, name=None, parent=None, attrs=None)
  `OrderReferenceDetails` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `SimpleList`(*args, **kw)
  `end`(name, value, *args, **kw)
  `start`(*args, **kw)

class `boto.mws.response.` `SubmitFeedResult`(connection=None, name=None, parent=None, attrs=None)
  `FeedSubmissionInfo` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `Subscription`(connection=None, name=None, parent=None, attrs=None)
  `Destination` = <Element_?/?_0x7ffd26b0f6e0>

class `boto.mws.response.` `UpdateReportAcknowledgementsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `VariationRelationship`(connection=None, name=None, parent=None, attrs=None)
  `GemType` = <SimpleList_?/?_0x7ffd26b51b90>
  `Identifiers` = <Element_?/?_0x7ffd26b0f6e0>
  `MaterialType` = <SimpleList_?/?_0x7ffd26b51b90>
  `OperatingSystem` = <SimpleList_?/?_0x7ffd26b51b90>

`boto.mws.response.` `strip_namespace`(func)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »